/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "$(appName).h"

static void
_drawer_cb(void *data, Evas_Object *obj, void *event_info)
{
	Evas_Object *panel = data;
	if (!elm_object_disabled_get(panel)) elm_panel_toggle(panel);
}

static void
_panel_toggle_cb(void *data, Evas_Object *obj, void *event_info)
{
	appdata_s *ad = data;
	if (!elm_object_disabled_get(ad->bottom_panel)) elm_panel_toggle(ad->bottom_panel);
}

static void
_panel_scroll_cb(void *data, Evas_Object *obj, void *event_info)
{
	Elm_Panel_Scroll_Info *ev = event_info;
	Evas_Object *bg = data;
	int col = 127 * ev->rel_x;

	/* Change color for background dim */
	evas_object_color_set(bg, 0, 0, 0, col);
}

static Evas_Object*
create_bg(Evas_Object *parent)
{
	Evas_Object *rect;
	rect = evas_object_rectangle_add(evas_object_evas_get(parent));
	evas_object_color_set(rect, 0, 0, 0, 0);
	evas_object_show(rect);

	return rect;
}

static Evas_Object*
create_panel(Evas_Object* parent)
{
	Evas_Object *panel, *list, *icon;
	char res_path[PATH_MAX] = {0, };

	/* Panel */
	panel = elm_panel_add(parent);
	elm_panel_scrollable_set(panel, EINA_TRUE);
	elm_panel_orient_set(panel, ELM_PANEL_ORIENT_LEFT);
	elm_panel_hidden_set(panel, EINA_TRUE);

	/* Appends List as Panel content */
	list = elm_list_add(panel);
	evas_object_size_hint_align_set(list, EVAS_HINT_FILL, EVAS_HINT_FILL);
	evas_object_size_hint_weight_set(list, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);

	app_get_resource("images/tizen.png", res_path, (int)PATH_MAX);

	icon = elm_image_add(list);
	elm_image_file_set(icon, res_path, NULL);
	evas_object_size_hint_min_set(icon, ELM_SCALE_SIZE(16), ELM_SCALE_SIZE(16));
	elm_list_item_append(list, "Library", icon, NULL, NULL, NULL);

	icon = elm_image_add(list);
	elm_image_file_set(icon, res_path, NULL);
	evas_object_size_hint_min_set(icon, ELM_SCALE_SIZE(16), ELM_SCALE_SIZE(16));
	elm_list_item_append(list, "Playlists", icon, NULL, NULL, NULL);

	icon = elm_image_add(list);
	elm_image_file_set(icon, res_path, NULL);
	evas_object_size_hint_min_set(icon, ELM_SCALE_SIZE(16), ELM_SCALE_SIZE(16));
	elm_list_item_append(list, "Settings", icon, NULL, NULL, NULL);

	elm_list_go(list);

	elm_object_content_set(panel, list);

	return panel;
}

static void
genre_view_add(void *data, Evas_Object *obj, void *ev_info)
{
	appdata_s *ad = data;
	int i;

	elm_list_clear(ad->list);

	for( i = 0; i < 8; i++)
		elm_list_item_append(ad->list, "Genre", NULL, NULL, NULL, NULL);

	elm_list_go(ad->list);
}

static void
artist_view_add(void *data, Evas_Object *obj, void *ev_info)
{
	appdata_s *ad = data;
	int i;

	elm_list_clear(ad->list);

	for( i = 0; i < 8; i++)
		elm_list_item_append(ad->list, "Artist Name", NULL, NULL, NULL, NULL);

	elm_list_go(ad->list);
}

static void
album_view_add(void *data, Evas_Object *obj, void *ev_info)
{
	appdata_s *ad = data;
	int i;

	elm_list_clear(ad->list);

	for( i = 0; i < 8; i++)
		elm_list_item_append(ad->list, "Album Title", NULL, NULL, NULL, NULL);


	elm_list_go(ad->list);
}

static void
song_view_add(void *data, Evas_Object *obj, void *ev_info)
{
	appdata_s *ad = data;
	int i;

	elm_list_clear(ad->list);

	for( i = 0; i < 8; i++)
		elm_list_item_append(ad->list, "Song Title", NULL, NULL, NULL, NULL);

	elm_list_go(ad->list);
}

static Evas_Object*
create_content(Evas_Object* parent, appdata_s *ad)
{
	Evas_Object *layout, *layout2, *toolbar, *image, *label, *list, *btn;
	Elm_Object_Item *tb_it;
	char res_path[PATH_MAX] = {0, };

	/* Base Layout for Naviframe's content */
	layout = elm_layout_add(parent);
	elm_layout_theme_set(layout, "layout", "musicplayer", "tabbar");

	/* Content (List) */
	list = elm_list_add(layout);
	evas_object_size_hint_align_set(list, EVAS_HINT_FILL, EVAS_HINT_FILL);
	evas_object_size_hint_weight_set(list, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);

	elm_object_part_content_set(layout, "content", list);
	ad->list = list;

	/* Tabbar */
	toolbar = elm_toolbar_add(layout);
	elm_object_style_set(toolbar, "tabbar");
	elm_toolbar_shrink_mode_set(toolbar, ELM_TOOLBAR_SHRINK_EXPAND);
	elm_toolbar_select_mode_set(toolbar, ELM_OBJECT_SELECT_MODE_ALWAYS);
	elm_toolbar_transverse_expanded_set(toolbar, EINA_TRUE);

	elm_toolbar_item_append(toolbar, NULL, "Genres", genre_view_add, ad);
	elm_toolbar_item_append(toolbar, NULL, "Artists", artist_view_add, ad);
	elm_toolbar_item_append(toolbar, NULL, "Albums", album_view_add, ad);
	tb_it = elm_toolbar_item_append(toolbar, NULL, "Songs", song_view_add, ad);

	elm_toolbar_item_selected_set(tb_it, EINA_TRUE);
	elm_object_part_content_set(layout, "top", toolbar);

	/* Miniplayer */
	layout2 = elm_layout_add(layout);
	elm_layout_theme_set(layout2, "layout", "musicplayer", "miniplayer");
	elm_object_part_content_set(layout, "bottom", layout2);

	/* Image */
	image = elm_image_add(layout2);
	app_get_resource("images/tizen.png", res_path, (int)PATH_MAX);
	elm_image_file_set(image, res_path, NULL);
	evas_object_size_hint_align_set(image, EVAS_HINT_FILL, EVAS_HINT_FILL);
	evas_object_size_hint_weight_set(image, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	evas_object_smart_callback_add(image, "clicked", _panel_toggle_cb, ad);
	elm_object_part_content_set(layout2, "icon", image);

	/* Label */
	label = elm_label_add(layout2);
	elm_object_style_set(label, "slide_long");
	elm_object_text_set(label, "<font color=#ffffff>Artist - Song Title</font>");
	elm_label_slide_duration_set(label, 5.0);
	elm_label_slide_mode_set(label, ELM_LABEL_SLIDE_MODE_NONE);
	elm_label_slide_go(label);
	evas_object_smart_callback_add(label, "clicked", _panel_toggle_cb, ad);
	elm_object_part_content_set(layout2, "label", label);
	ad->label = label;

	/* Button (Play/Pause) */
	btn = elm_button_add(layout2);
	evas_object_smart_callback_add(btn, "clicked", _play_btn_cb, ad);
	elm_object_part_content_set(layout2, "end", btn);
	ad->lib_btn = btn;

	image = elm_image_add(btn);
	app_get_resource("images/play.png", res_path, (int)PATH_MAX);
	elm_image_file_set(image, res_path, NULL);
	elm_object_content_set(btn, image);

	return layout;
}

Evas_Object*
create_library_view(appdata_s *ad)
{
	Evas_Object *nf, *layout, *layout2, *bg, *btn;
	Elm_Object_Item *nf_it;

	nf = elm_naviframe_add(ad->layout);

	/* Base Layout in Naviframe for Left Panel and Content */
	layout = elm_layout_add(nf);
	elm_layout_theme_set(layout, "layout", "drawer", "panel");

	/* Left Panel */
	ad->left_panel = create_panel(layout);
	elm_object_part_content_set(layout, "elm.swallow.left", ad->left_panel);

	/* Panel Background (Dimmed Area) */
	bg = create_bg(layout);
	evas_object_smart_callback_add(ad->left_panel, "scroll", _panel_scroll_cb, bg);
	elm_object_part_content_set(layout, "elm.swallow.bg", bg);

	/* Content */
	layout2 = create_content(layout, ad);
	elm_object_part_content_set(layout, "elm.swallow.content", layout2);

	/* Push the Layout as Naviframe Item */
	nf_it = elm_naviframe_item_push(nf, "Music Player", NULL, NULL, layout, "drawers");

	/* Left Panel Toggle Button */
	btn = elm_button_add(nf);
	elm_object_style_set(btn, "naviframe/drawers");
	evas_object_smart_callback_add(btn, "clicked", _drawer_cb, ad->left_panel);
	elm_object_item_part_content_set(nf_it, "drawers", btn);

	return nf;
}
