/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "$(appName).h"

static void
_timer_start(appdata_s *ad)
{
	ecore_timer_reset(ad->timer);
	ecore_timer_thaw(ad->timer);
}

static void
_timer_stop(appdata_s *ad)
{
	ecore_timer_freeze(ad->timer);
}

Eina_Bool
_timer_update_cb(void *data)
{
	appdata_s *ad = data;
	double ms;

	ms = elm_slider_value_get(ad->slider);

	if(ms < SONG_LENGTH)
		ms += TIMER_UPDATE_PERIOD;
	else
		ms = 0.;

	elm_slider_value_set(ad->slider, ms);

	return EINA_TRUE;
}

void
_play_btn_cb(void *data, Evas_Object *obj, void *event_info)
{
	appdata_s *ad = data;
	char res_path[PATH_MAX];

	Evas_Object *image;
	Elm_Label_Slide_Mode elsm;

	elsm = elm_label_slide_mode_get(ad->label);

	if (elsm == ELM_LABEL_SLIDE_MODE_NONE) {
		elm_label_slide_mode_set(ad->label, ELM_LABEL_SLIDE_MODE_ALWAYS);

		app_get_resource("images/pause.png", res_path, (int)PATH_MAX);

		image = elm_object_content_get(ad->lib_btn);
		elm_image_file_set(image, res_path, NULL);

		image = elm_object_content_get(ad->play_btn);
		elm_image_file_set(image, res_path, NULL);

		_timer_start(ad);
	}
	else {
		elm_label_slide_mode_set(ad->label, ELM_LABEL_SLIDE_MODE_NONE);

		app_get_resource("images/play.png", res_path, (int)PATH_MAX);

		image = elm_object_content_get(ad->lib_btn);
		elm_image_file_set(image, res_path, NULL);

		image = elm_object_content_get(ad->play_btn);
		elm_image_file_set(image, res_path, NULL);

		_timer_stop(ad);
	}

	elm_label_slide_go(ad->label);
}

static void
_next_btn_cb(void *data, Evas_Object *obj, void *event_info)
{
	appdata_s *ad = data;
	elm_slider_value_set(ad->slider, 0.);
}

static void
_panel_toggle_cb(void *data, Evas_Object *obj, void *event_info)
{
	Evas_Object *panel = data;
	elm_panel_hidden_set(panel, EINA_TRUE);
}

Evas_Object*
create_player_view(appdata_s *ad)
{
	Evas_Object *panel, *layout, *layout2, *image, *label, *slider, *btn;
	char res_path[PATH_MAX] = {0, };

	/* Append Bottom Panel for Player View */
	panel = elm_panel_add(ad->layout);
	elm_object_style_set(panel, "custom");
	elm_panel_scrollable_set(panel, EINA_FALSE);
	elm_panel_orient_set(panel, ELM_PANEL_ORIENT_BOTTOM);
	elm_panel_hidden_set(panel, EINA_TRUE);

	/* Base Layout */
	layout = elm_layout_add(panel);
	elm_layout_theme_set(layout, "layout", "musicplayer", "player");
	evas_object_size_hint_align_set(layout, EVAS_HINT_FILL, EVAS_HINT_FILL);
	evas_object_size_hint_weight_set(layout, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	elm_object_content_set(panel, layout);

	/* MiniPlayer */
	layout2 = elm_layout_add(layout);
	elm_layout_theme_set(layout2, "layout", "musicplayer", "miniplayer");
	elm_object_part_content_set(layout, "top", layout2);

	/* Back Button */
	btn = elm_button_add(layout2);
	evas_object_smart_callback_add(btn, "clicked", _panel_toggle_cb, panel);
	elm_object_part_content_set(layout2, "icon", btn);

	image = elm_image_add(btn);
	app_get_resource("images/back.png", res_path, (int)PATH_MAX);
	elm_image_file_set(image, res_path, NULL);
	elm_object_content_set(btn, image);

	/* Label (Title) */
	label = elm_label_add(layout2);
	elm_object_text_set(label, "<font color=#ffffff align=center>Artist - Song Title</font>");
	evas_object_smart_callback_add(label, "clicked", _panel_toggle_cb, panel);
	elm_object_part_content_set(layout2, "label", label);

	/* Center Image (Album Cover) */
	image = elm_image_add(layout);
	app_get_resource("images/tizen.png", res_path, (int)PATH_MAX);
	elm_image_file_set(image, res_path, NULL);
	evas_object_size_hint_align_set(image, EVAS_HINT_FILL, EVAS_HINT_FILL);
	evas_object_size_hint_weight_set(image, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	elm_object_part_content_set(layout, "content", image);

	/* Slider for Progressbar */
	slider = elm_slider_add(layout);
	elm_slider_indicator_show_set(slider, EINA_FALSE);
	evas_object_size_hint_align_set(slider, 0.5, 1.0);
	evas_object_size_hint_weight_set(slider, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
	elm_slider_indicator_format_set(slider, "%1.0f");
	elm_slider_min_max_set(slider, 0., SONG_LENGTH);
	elm_object_part_content_set(layout, "slider", slider);
	ad->slider = slider;

	/* Control Buttons (Rew/Play/FastFoward)*/
	layout2 = elm_layout_add(layout);
	elm_layout_theme_set(layout2, "layout", "musicplayer", "controls");
	elm_object_part_content_set(layout, "bottom", layout2);

	btn = elm_button_add(layout2);
	evas_object_smart_callback_add(btn, "clicked", _play_btn_cb, ad);
	elm_object_part_content_set(layout2, "play_btn", btn);
	ad->play_btn = btn;

	image = elm_image_add(btn);
	app_get_resource("images/play.png", res_path, (int)PATH_MAX);
	elm_image_file_set(image, res_path, NULL);
	elm_object_content_set(btn, image);

	btn = elm_button_add(layout2);
	evas_object_smart_callback_add(btn, "clicked", _next_btn_cb, ad);
	elm_object_part_content_set(layout2, "rew_btn", btn);

	image = elm_image_add(btn);
	app_get_resource("images/rewind.png", res_path, (int)PATH_MAX);
	elm_image_file_set(image, res_path, NULL);
	elm_object_content_set(btn, image);

	btn = elm_button_add(layout2);
	evas_object_smart_callback_add(btn, "clicked", _next_btn_cb, ad);
	elm_object_part_content_set(layout2, "ff_btn", btn);

	image = elm_image_add(btn);
	app_get_resource("images/fastforward.png", res_path, (int)PATH_MAX);
	elm_image_file_set(image, res_path, NULL);
	elm_object_content_set(btn, image);

	return panel;
}
